Crate waverave_hackrf

Modules

debug
info

Structs

BiasTSetting
Configuration settings for the Bias-T switch.
Buffer
A Buffer holding HackRF transfer data.
HackRf
A HackRF device. This is the main struct for talking to the HackRF.
HackRfDescriptor
A HackRF device descriptor, which can be opened.
OperacakeDwell
A dwell time allocated to a specific port for all Operacakes operating in dwell time mode.
OperacakeFreq
A Frequency band allocated to a specific port for all Operacakes operating in frequency mode.
Receive
A HackRF operating in receive mode.
StateChangeError
An error from trying to change HackRF states and failing.
Sweep
A HackRF operating in sweep mode.
SweepBuf
SweepParams
Configuration settings for a receive sweep across multiple frequencies.
Transmit
A HackRF operating in transmit mode.

Enums

BiasTMode
A Bias-T setting change to apply on a mode change.
Error
HackRfType
The type of HackRF device that was detected.
OperacakeMode
Configuration for an Operacake board.
RfPathFilter
RF Filter Setting Option.

Constants

PORT_A1
Operacake port A1
PORT_A2
Operacake port A2
PORT_A3
Operacake port A3
PORT_A4
Operacake port A4
PORT_B1
Operacake port B1
PORT_B2
Operacake port B2
PORT_B3
Operacake port B3
PORT_B4
Operacake port B4

Functions

list_hackrf_devices
List all available HackRF devices.
open_hackrf
Open the first detected HackRF device in the system.

Type Aliases

ComplexI8
Complex 8-bit signed data, as used by the HackRF.