#[repr(u16)]pub enum OperacakeMode {
Manual = 0,
Frequency = 1,
Time = 2,
}Expand description
Configuration for an Operacake board.
An Operacake board has three different operating modes:
- Manual: the switches are manually set and don’t change until the next configuration operation.
- Frequency: the switches change depending on the center frequency the board is tuned to.
- Time: the switches change after some number of samples have been sent/received.
Use when calling HackRf::operacake_set_mode.
Variants