pub struct BiasTSetting {
pub tx: BiasTMode,
pub rx: BiasTMode,
pub off: BiasTMode,
}Expand description
Configuration settings for the Bias-T switch.
Used when calling HackRf::set_user_bias_t_opts.
Fields
tx: BiasTModeWhat mode change to apply when switching to transmit.
rx: BiasTModeWhat mode change to apply when switching to receive.
off: BiasTModeWhat mode change to apply when switching off.