OperacakeDwell

Struct OperacakeDwell 

pub struct OperacakeDwell {
    pub dwell: u32,
    pub port: u8,
}
A dwell time allocated to a specific port for all Operacakes operating in dwell time mode.

This is used in HackRf::operacake_config_time.

Ports are zero-indexed, but can also be referred to with the top-level constants:

  • PORT_A1 = 0
  • PORT_A2 = 1
  • PORT_A3 = 2
  • PORT_A4 = 3
  • PORT_B1 = 4
  • PORT_B2 = 5
  • PORT_B3 = 6
  • PORT_B4 = 7

Fields

dwell: u32

Dwell time, in number of samples

port: u8

Port for A0 to use for the range. B0 will use the mirror image.