pub struct OperacakeFreq {
pub min: u16,
pub max: u16,
pub port: u8,
}Expand description
A Frequency band allocated to a specific port for all Operacakes operating in frequency mode.
This is used in HackRf::operacake_config_freq.
Ports are zero-indexed, but can also be referred to with the top-level constants:
- PORT_A1 = 0
- PORT_A2 = 1
- PORT_A3 = 2
- PORT_A4 = 3
- PORT_B1 = 4
- PORT_B2 = 5
- PORT_B3 = 6
- PORT_B4 = 7
Fields
min: u16Start frequency, in MHz.
max: u16Stop frequency, in MHz.
port: u8Port for A0 to use for the range. B0 will use the mirror image.