Module debug

Debug operations for the HackRF.

The HackRF exposes a number of internal debugging operations through the Debug struct, allowing for direct read & write of most peripheral ICs. This is also how it can be reprogrammed without entering the DFU mode.

The way to do this with a HackRF is by calling HackRf::debug with an open peripheral, like so:



use waverave_hackrf::debug::*;

let mut hackrf = waverave_hackrf::open_hackrf()?;
// Mutably borrow - make sure no other operations are in progress.
let mut debug = hackrf.debug();

// Just grab the internal state of the M0 processor and dump it
let state = debug.get_m0_state().await?;
dbg!(&state);

Structs

Debug
Debug operations for the HackRF, including programming operations.
M0State
Internal state data of the Cortex M0 sub-processor.
SpiFlash
Accessor for the W25Q80BV SPI Flash in the HackRF.