pub struct Debug<'a> { /* private fields */ }Expand description
Debug operations for the HackRF, including programming operations.
Borrows the interface while doing operations.
Implementations
Sourceimpl<'a> Debug<'a>
impl<'a> Debug<'a>
Sourcepub async fn get_m0_state(&self) -> Result<M0State, Error>
pub async fn get_m0_state(&self) -> Result<M0State, Error>
Get the internal state of the M0 code of the LPC43xx MCU.
Requires API version 0x0106 or higher.
Sourcepub async fn cpld_write<F>(
&mut self,
data: &[u8],
callback: Option<F>,
) -> Result<(), Error>
pub async fn cpld_write<F>( &mut self, data: &[u8], callback: Option<F>, ) -> Result<(), Error>
Update the XC2C64A-7VQ100C CPLD with a new bitstream.
After every transfer completes, an optional callback will be invoked with the number of bytes transferred as the first argument, and the total number of bytes to be transferred as the second argument.
Sourcepub async fn cpld_checksum(&self) -> Result<u32, Error>
pub async fn cpld_checksum(&self) -> Result<u32, Error>
Get the checksum of the CPLD bitstream.
Requires API version 0x0103 or higher.
Sourcepub async fn si5351c_read(&self, register: u8) -> Result<u8, Error>
pub async fn si5351c_read(&self, register: u8) -> Result<u8, Error>
Read a register from the SI5351C.
Sourcepub async fn si5351c_write(&self, register: u8, value: u8) -> Result<(), Error>
pub async fn si5351c_write(&self, register: u8, value: u8) -> Result<(), Error>
Write a register to the SI5351C.
Sourcepub async fn rffc5071_read(&self, register: u8) -> Result<u16, Error>
pub async fn rffc5071_read(&self, register: u8) -> Result<u16, Error>
Read a register from the RFFC5071.
Sourcepub async fn rffc5071_write(
&self,
register: u8,
value: u16,
) -> Result<(), Error>
pub async fn rffc5071_write( &self, register: u8, value: u16, ) -> Result<(), Error>
Write a register to the RFFC5071.