Struct SpiFlash

pub struct SpiFlash<'a> { /* private fields */ }
Accessor for the W25Q80BV SPI Flash in the HackRF.

Implementations

Source

impl SpiFlash<'_>

pub async fn erase(&self) -> Result<(), Error>

Erase the entire flash memory.

Should be immediately followed by writing a new image, or the HackRF will be soft-bricked (but recoverable by DFU).

pub async fn write(&self, addr: u32, data: &[u8]) -> Result<(), Error>

Write firmware to the flash memory.

Should only be used for firmware image writing, and likely needs to be preceeded by an erase command before doing a write sequence.

Writes can be up to the max size of the memory; this command will split them into sub-commands if needed.

pub async fn read(&self, addr: u32, len: usize) -> Result<Vec<u8>, Error>

Read from the flash memory.

This should only be used for firmware verification.

Reads can be up to the max size of the memory; this command will split them into sub-commands if needed.

pub async fn status(&self) -> Result<[u8; 2], Error>

Get the status registers of the W25Q80BV flash memory.

Requires API version 0x0103 or higher.

pub async fn clear_status(&self) -> Result<(), Error>

Clear the status registers of the W25Q80BV flash memory.