pub struct Sweep { /* private fields */ }Expand description
A HackRF operating in sweep mode.
Implementations
Sourceimpl Sweep
impl Sweep
Sourcepub async fn new(
rf: HackRf,
params: &SweepParams,
) -> Result<Self, StateChangeError>
pub async fn new( rf: HackRf, params: &SweepParams, ) -> Result<Self, StateChangeError>
Start a new RX sweep using the provided parameters.
The size of each internal USB block transfer can be set,
Sourcepub async fn new_with_custom_sample_rate(
rf: HackRf,
params: &SweepParams,
) -> Result<Self, StateChangeError>
pub async fn new_with_custom_sample_rate( rf: HackRf, params: &SweepParams, ) -> Result<Self, StateChangeError>
Start a new RX sweep without configuring the sample rate or baseband filter.
Sourcepub fn submit(&mut self)
pub fn submit(&mut self)
Queue up a sweep transfer.
This will pull from a reusable buffer pool first, and allocate a new buffer if none are available in the pool.
The buffer pool will grow so long as completed buffers aren’t dropped.
Sourcepub async fn next_complete(&mut self) -> Result<SweepBuf, Error>
pub async fn next_complete(&mut self) -> Result<SweepBuf, Error>
Retrieve the next chunk of receive data.