Struct SweepParams

pub struct SweepParams {
    pub sample_rate_hz: u32,
    pub freq_mhz: Vec<(u16, u16)>,
    pub blocks_per_tuning: u16,
    pub step_width_hz: u32,
    pub offset_hz: u32,
    pub mode: SweepMode,
}
Configuration settings for a receive sweep across multiple frequencies.

Fields

sample_rate_hz: u32

Sample rate to operate at.

freq_mhz: Vec<(u16, u16)>

List of frequency pairs to sweep over, in MHz. There can be up to 10.

blocks_per_tuning: u16

Number of blocks to capture per tuning. Each block is 16384 bytes, or 8192 samples.

step_width_hz: u32

Width of each tuning step, in Hz. sample_rate is a good value, in general.

offset_hz: u32

Frequency offset added to tuned frequencies. Sample_rate*3/8 is a good value for Interleaved sweep mode.

mode: SweepMode

Sweep mode.

Implementations

Source

impl SweepParams

pub fn initialize_from_sample_rate(sample_rate_hz: u32) -> Self